@@ -1,7 +1,5 @@
-/*
- * $Header: /home/dmarkle/xtrkcad-fork-cvs/xtrkcad/app/bin/ctodesgn.c,v 1.5 2009-06-20 09:20:49 m_fischer Exp $
- *
- * T_TURNOUT
+/* \file ctodesgn.c
+ * T_TURNOUT Designer
  *
  */
 
@@ -1408,7 +1406,7 @@ static void NewTurnPrint(
 			newTurnout_d.d = wPrintPageStart();
 			newTurnout_d.dpi = wDrawGetDPI(newTurnout_d.d);
 
-			sprintf( message, sProdName );
+			sprintf( message, "%s", sProdName );
 			wDrawString( newTurnout_d.d, POSX(3.0),
 						POSY(6.75), 0.0, message, fp, 40,
 						wDrawColorBlack, 0 );
@@ -1830,7 +1828,7 @@ EXPORT void EditCustomTurnout( turnoutInfo_t * to, turnoutInfo_t * to1 )
 		return;
 	for ( i=0; i<(sizeof designDescs/sizeof designDescs[0]); i++ ) {
 		dp = designDescs[i];
-		if ( strcmp( type, _(dp->label) ) == 0 ) {
+		if ( strcmp( type, dp->label ) == 0 ) {
 			break;
 		}
 	}
@@ -2044,7 +2042,7 @@ EXPORT void AbortProg(
 	va_start( ap, msg );
 	vsprintf( message, msg, ap );
 	va_end( ap );
-	fprintf( stderr, message );
+	fprintf( stderr, "%s", message );
 	abort();
 }
 
