@@ -1,7 +1,5 @@
 /** \file misc2.c
  * Management of information about scales and gauges plus rprintf.
- *
- * $Header: /home/dmarkle/xtrkcad-fork-cvs/xtrkcad/app/bin/misc2.c,v 1.9 2009-10-04 16:46:39 m_fischer Exp $
  */
 
 /*  XTrkCad - Model Railroad CAD
@@ -53,8 +51,8 @@ EXPORT long checkPtInterval = 10;
 EXPORT DIST_T curScaleRatio;
 EXPORT char * curScaleName;
 EXPORT DIST_T trackGauge;
-EXPORT char Title1[40] = "";
-EXPORT char Title2[40] = "Title line 2";
+EXPORT char Title1[TITLEMAXLEN] = "";
+EXPORT char Title2[TITLEMAXLEN] = "Title line 2";
 EXPORT long labelScale = 8;
 EXPORT long labelEnable = ((1<<0)|LABELENABLE_LENGTHS|LABELENABLE_ENDPT_ELEV|LABELENABLE_CARS);
 EXPORT long labelWhen = 2;
@@ -91,9 +89,9 @@ EXPORT void Rdump( FILE * outf )
 {
 	fprintf( outf, "Record Buffer:\n" );
 	rbuff[RBUFF_SIZE] = '\0';
-	fprintf( outf, rbuff+roff );
+	fprintf( outf, "%s", rbuff+roff );
 	rbuff[roff] = '\0';
-	fprintf( outf, rbuff );
+	fprintf( outf, "%s", rbuff );
 	memset( rbuff, 0, sizeof rbuff );
 	roff = 0;
 }
@@ -190,7 +188,7 @@ typedef struct {
 
 EXPORT typedef gaugeInfo_t * gaugeInfo_p;
 
-EXPORT GAUGEINX_T curGaugeInx = -1;
+EXPORT GAUGEINX_T curGaugeInx = 0;
 
 /** this struct holds a scale description */
 typedef struct {
@@ -203,7 +201,8 @@ typedef struct {
 EXPORT typedef scaleDesc_t *scaleDesc_p;
 static dynArr_t scaleDesc_da;
 #define scaleDesc(N) DYNARR_N( scaleDesc_t, scaleDesc_da, N )
-EXPORT SCALEDESCINX_T curScaleDescInx = -1;
+
+EXPORT SCALEDESCINX_T curScaleDescInx;
 
 /**
  * Get the ratio from a scale description. Each member in the list of scale descriptions is
